@@ -32,6 +32,9 @@ class DatetimeTransformer(BaseTransformer):
             values by the value of the next smallest time unit. This, a part from reducing the
             orders of magnitued of the transformed values, ensures that reverted values always
             are zero on the lower time units.
+        format (str):
+            The strftime to use for parsing time. For more information, see
+            https://docs.python.org/3/library/datetime.html#strftime-and-strptime-behavior.
     """
 
     INPUT_TYPE = 'datetime'
@@ -42,10 +45,11 @@ class DatetimeTransformer(BaseTransformer):
     null_transformer = None
     divider = None
 
-    def __init__(self, nan='mean', null_column=None, strip_constant=False):
+    def __init__(self, nan='mean', null_column=None, strip_constant=False, datetime_format=None):
         self.nan = nan
         self.null_column = null_column
         self.strip_constant = strip_constant
+        self.datetime_format = datetime_format
 
     def is_composition_identity(self):
         """Return whether composition of transform and reverse transform produces the input data.
@@ -84,8 +88,23 @@ class DatetimeTransformer(BaseTransformer):
 
             self.divider = candidate
 
+    def _convert_to_datetime(self, data):
+        if data.dtype == 'object':
+            try:
+                data = pd.to_datetime(data, format=self.datetime_format)
+
+            except ValueError as error:
+                if 'Unknown string format:' in str(error):
+                    message = 'Data must be of dtype datetime, or castable to datetime.'
+                    raise TypeError(message) from None
+
+                raise ValueError('Data does not match specified datetime format.') from None
+
+        return data
+
     def _transform_helper(self, datetimes):
         """Transform datetime values to integer."""
+        datetimes = self._convert_to_datetime(datetimes)
         nulls = datetimes.isna()
         integers = pd.to_numeric(datetimes, errors='coerce').to_numpy().astype(np.float64)
         integers[nulls] = np.nan
@@ -101,7 +120,7 @@ class DatetimeTransformer(BaseTransformer):
         """Fit the transformer to the data.
 
         Args:
-            data (pandas.Series:
+            data (pandas.Series):
                 Data to fit the transformer to.
         """
         transformed = self._transform_helper(data)
